@@ -1,5 +1,5 @@
 <?php
-// $Id: cron.php,v 1.26 2004/09/09 05:51:07 dries Exp $
+// $Id: cron.php,v 1.28 2005-01-09 09:22:38 dries Exp $
 
 /**
  * @file
@@ -16,7 +16,7 @@ if (!ini_get('safe_mode')) {
 
 // Check if the last cron run completed
 if (variable_get('cron_busy', false)) {
-  watchdog('warning', t('Last cron run did not complete.'));
+  watchdog('cron', t('Last cron run did not complete.'), WATCHDOG_WARNING);
 }
 else {
   variable_set('cron_busy', true);
@@ -27,6 +27,6 @@ module_invoke_all('cron');
 
 // Clean up
 variable_set('cron_busy', false);
-watchdog('regular', t('Cron run completed'));
+watchdog('cron', t('Cron run completed'));
 
 ?>
