@@ -1,5 +1,5 @@
 <?php
-// $Id: update.php,v 1.142.2.3 2005/01/13 19:25:30 dries Exp $
+// $Id: update.php,v 1.147 2005-04-06 19:04:02 dries Exp $
 
 /**
  * @file
@@ -36,6 +36,7 @@ function update_data($start) {
     variable_set("update_start", $date);
     print "</pre>\n";
   }
+  db_query('DELETE FROM {cache}');
 }
 
 function update_page_header($title) {
@@ -85,13 +86,15 @@ function update_page() {
       print update_page_footer();
       break;
     default:
-      // NOTE: We need the following five lines in order to fix a bug with database.mysql (http://drupal.org/node/15337)
-      //       We should be able to remove them in the future.
-      $result = db_query("SELECT * FROM variable WHERE name = 'update_start' AND value LIKE '%;\"'");
+      // NOTE: We need the following five lines in order to fix a bug with
+      //       database.mysql (issue #15337).  We should be able to remove
+      //       this work around in the future.
+      $result = db_query("SELECT * FROM {variable} WHERE name = 'update_start' AND value LIKE '%;\"'");
       if ($variable = db_fetch_object($result)) {
         $variable->value = unserialize(substr($variable->value, 0, -2) .'";');
         variable_set('update_start', $variable->value);
       }
+
       $start = variable_get("update_start", 0);
       $dates[] = "All";
       $i = 1;
@@ -212,7 +215,14 @@ if (isset($_GET["op"])) {
   }
   else {
     print update_page_header("Access denied");
-    print "Access denied.  You are not authorized to access to this page.  Please log in as the user with user ID #1. If you cannot log-in, you will have to edit <code>update.php</code> to by-pass this access check; in that case, open <code>update.php</code> in a text editor and follow the instructions at the top.";
+    print "<p>Access denied.  You are not authorized to access this page.  Please log in as the admin user (the first user you created). If you cannot log in, you will have to edit <code>update.php</code> to bypass this access check.  To do this:</p>";
+    print "<ol>";
+    print " <li>With a text editor find the update.php file on your system. It should be in the main Drupal directory that you installed all the files into.</li>";
+    print " <li>There is a line near top of update.php that says <code>\$access_check = TRUE;</code>. Change it to <code>\$access_check = FALSE;</code>.</li>";
+    print " <li>As soon as the script is done, you must change the update.php script back to its original form to <code>\$access_check = TRUE;</code>.</li>";
+    print " <li>To avoid having this problem in future, remember to log in to your website as the admin user (the user you first created) before you backup your database at the beginning of the update process.</li>";
+    print "</ol>";
+
     print update_page_footer();
   }
 }
